@@ -922,21 +922,21 @@ EOT
           Whether certificate revocation checking should be enabled, and what level of
           checking should be performed.
 
-          When certificate revocation is enabled Puppet expects the contents of its CRL
-          to be one or more PEM encoded CRLs concatenated together. When using a cert
-          bundle CRLs for all CAs in the chain of trust must be included in the crl file
-          with the first CRL listed being for the root of the chain, the last being for
-          the leaf CA.
+          When certificate revocation is enabled, Puppet expects the contents of its CRL
+          to be one or more PEM-encoded CRLs concatenated together. When using a cert
+          bundle, CRLs for all CAs in the chain of trust must be included in the crl file.
+          The chain should be ordered from least to most authoritative, with the first CRL
+          listed being for the root of the chain and the last being for the leaf CA.
 
-          When certificate_revocation is set to 'true' or 'chain', Puppet will ensure
+          When certificate_revocation is set to 'true' or 'chain', Puppet ensures
           that each CA in the chain of trust has not been revoked by its issuing CA.
 
-          When certificate_revocation is set to 'leaf', Puppet will verify certs against
-          the issuing CA's revocation list but not verify the revocation status of the
-          issuing CA or any CA above it within the chain of trust.
+          When certificate_revocation is set to 'leaf', Puppet verifies certs against
+          the issuing CA's revocation list, but it does not verify the revocation status
+          of the issuing CA or any CA above it within the chain of trust.
 
-          When certificate_revocation is set to 'false', Puppet will disable all
-          certificate revocation checking and will not attempt to download the CRL.
+          When certificate_revocation is set to 'false', Puppet disables all
+          certificate revocation checking and does not attempt to download the CRL.
         EOT
     },
     :digest_algorithm => {
@@ -1948,6 +1948,16 @@ EOT
       referencing variables that are explicitly set to undef).
     EOT
     },
+   :func3x_check => {
+     :default => true,
+     :type => :boolean,
+     :desc => <<-'EOT'
+       Causes validation of loaded legacy Ruby functions (3x API) to raise errors about illegal constructs that
+       could cause harm or that simply does not work. This flag is on by default. This flag is made available
+       so that the validation can be turned off in case the method of validation is faulty - if encountered, please
+       file a bug report.
+     EOT
+     },
   :tasks => {
     :default => false,
     :type => :boolean,
