@@ -1,7 +1,14 @@
 require 'puppet/provider/package'
 
 Puppet::Type.type(:package).provide :pkg, :parent => Puppet::Provider::Package do
-  desc "OpenSolaris image packaging system. See pkg(5) for more information."
+  desc "OpenSolaris image packaging system. See pkg(5) for more information.
+
+    This provider supports the `install_options` attribute, which allows
+    command-line flags to be passed to pkg. These options should be specified:
+    - as a string (for example, '--flag'), or
+    - as a hash (for example, {'--flag' => 'value'}), or
+    - as an array where each element is either a string or a hash."
+
   # https://docs.oracle.com/cd/E19963-01/html/820-6572/managepkgs.html
   # A few notes before we start:
   # Opensolaris pkg has two slightly different formats (as of now.)
@@ -19,6 +26,8 @@ Puppet::Type.type(:package).provide :pkg, :parent => Puppet::Provider::Package d
 
   has_feature :holdable
 
+  has_feature :install_options
+
   commands :pkg => "/usr/bin/pkg"
 
   confine :osfamily => :solaris
@@ -152,7 +161,9 @@ Puppet::Type.type(:package).provide :pkg, :parent => Puppet::Provider::Package d
       end
       potential_matches.each{ |p|
         command = is == :absent ? 'install' : 'update'
-        status = exec_cmd(command(:pkg), command, '-n', "#{name}@#{p[:ensure]}")[:exit]
+        options = ['-n']
+        options.concat(join_options(@resource[:install_options])) if @resource[:install_options]
+        status = exec_cmd(command(:pkg), command, *options, "#{name}@#{p[:ensure]}")[:exit]
         case status
         when 4
           # if the first installable match would cause no changes, we're in sync
@@ -174,6 +185,9 @@ Puppet::Type.type(:package).provide :pkg, :parent => Puppet::Provider::Package d
   # http://defect.opensolaris.org/bz/show_bug.cgi?id=19159%
   # notes that we can't use -Ha for the same even though the manual page reads that way.
   def latest
+    # Refresh package metadata before looking for latest versions
+    pkg(:refresh)
+
     lines = pkg(:list, "-Hvn", @resource[:name]).split("\n")
 
     # remove certificate expiration warnings from the output, but report them
@@ -187,8 +201,12 @@ Puppet::Type.type(:package).provide :pkg, :parent => Puppet::Provider::Package d
     # Now we know there is a newer version. But is that installable? (i.e are there any constraints?)
     # return the first known we find. The only way that is currently available is to do a dry run of
     # pkg update and see if could get installed (`pkg update -n res`).
-    known = lst.find {|p| p[:status] == 'known' }
-    return known[:ensure] if known and exec_cmd(command(:pkg), 'update', '-n', @resource[:name])[:exit].zero?
+    known = lst.find { |p| p[:status] == 'known' }
+    if known
+      options = ['-n']
+      options.concat(join_options(@resource[:install_options])) if @resource[:install_options]
+      return known[:ensure] if exec_cmd(command(:pkg), 'update', *options, @resource[:name])[:exit].zero?
+    end
 
     # If not, then return the installed, else nil
     (lst.find {|p| p[:status] == 'installed' } || {})[:ensure]
@@ -210,6 +228,7 @@ Puppet::Type.type(:package).provide :pkg, :parent => Puppet::Provider::Package d
     if Puppet::Util::Package.versioncmp(Facter.value(:operatingsystemrelease), '11.2') >= 0
       args.push('--sync-actuators-timeout', '900')
     end
+    args.concat(join_options(@resource[:install_options])) if @resource[:install_options]
     unless should.is_a? Symbol
       name += "@#{should}"
     end
